@@ -263,6 +263,7 @@ int  PropsApply()
         "Ok", ErrorDismiss_CB, (XtPointer) error_shell);
 
       XtPopup(error_shell, XtGrabExclusive);
+      XSetWMProtocols(disp,XtWindow(error_shell),&wm_delete_window,1);
 
 #endif /* TK==TK_XAW */
       return 0;
@@ -680,8 +681,12 @@ void  PropsPopup()
 }
 #endif /* TK_MOTIF */
 
-  XtPopup(props.shell, XtGrabNone);
-}
+   XtPopup(props.shell, XtGrabNone);
+
+#if TK==TK_XAW
+   XSetWMProtocols(disp,XtWindow(props.shell),&wm_delete_window,1);
+#endif
+} /* End of PropsPopup */
 #else /* TK_NONE */
 void PropsPopup() {}
 #endif
